@@ -18,11 +18,12 @@ With this module you can manage user and groups.
     create_user "root" => {
        uid => 0,
        home => '/root',
-       commenct => 'Root Account',
+       comment => 'Root Account',
        expire => '2011-05-30',
        groups  => ['root', '...'],
        password => 'blahblah',
        system => 1,
+       ssh_key => "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQChUw...",
     };
  };
 
@@ -58,7 +59,29 @@ Create or update a user.
 =cut
 
 sub create_user {
-   Rex::User->get()->create_user(@_);
+   my ($user, $data) = @_;
+   my $uid = Rex::User->get()->create_user(@_);
+
+   if(defined $data->{"ssh_key"} && ! defined $data->{"home"}) {
+      Rex::Logger::debug("If ssh_key option is used you have to specify home, too.");
+      die("If ssh_key option is used you have to specify home, too.");
+   }
+
+   if(defined $data->{"ssh_key"}) {
+
+      if(! is_dir($data->{"home"} . "/.ssh")) {
+         mkdir $data->{"home"} . "/.ssh",
+            owner => $user,
+            mode  => 700;
+      }
+
+      my $fh = file_write $data->{"home"} . "/.ssh/authorized_keys";
+      $fh->write($data->{"ssh_key"});
+      $fh->close;
+
+   }
+
+   return $uid;
 }
 
 =item get_uid($user)
