@@ -96,10 +96,27 @@ sub create_task {
          private_key => Rex::Config->get_private_key,
          public_key  => Rex::Config->get_public_key,
       },
+      before => [],
+      after  => [],
+      around => [],
    };
 
 }
 
+sub modify_task {
+   my $class = shift;
+   my $task  = shift;
+   my $key   = shift;
+   my $value = shift;
+
+   if(ref($tasks{$task}->{$key}) eq "ARRAY") {
+      push(@{ $tasks{$task}->{$key} }, $value);
+   }
+   else {
+      $tasks{$task}->{$key} = $value;
+   }
+}
+
 sub get_tasks {
    my $class = shift;
 
@@ -237,6 +254,16 @@ sub run {
             # reconnect to logger
             Rex::Logger::init();
 
+            # before jobs
+            for my $code (@{$tasks{$task}->{"before"}}) {
+               &$code($server);
+            }
+
+            # around jobs
+            for my $code (@{$tasks{$task}->{"around"}}) {
+               &$code($server);
+            }
+
             # this must be a ssh connection
             if(! $tasks{$task}->{"no_ssh"}) {
                $ssh = Net::SSH2->new;
@@ -264,10 +291,21 @@ sub run {
                Rex::Logger::info("Connected to $server, trying to authenticate.");
 
                my $auth_ret;
-               $auth_ret = $ssh->auth('username' => $user,
-                                      'password' => $pass,
-                                      'publickey' => $public_key,
-                                      'privatekey' => $private_key);
+               if(Rex::Config->get_password_auth) {
+                  $auth_ret = $ssh->auth_password($user, $pass);
+               }
+               elsif(Rex::Config->get_key_auth) {
+                  $auth_ret = $ssh->auth_publickey($user, 
+                                          $public_key, 
+                                          $private_key, 
+                                          $pass);
+               }
+               else {
+                  $auth_ret = $ssh->auth('username' => $user,
+                                         'password' => $pass,
+                                         'publickey' => $public_key,
+                                         'privatekey' => $private_key);
+               }
 
                # push a remote connection
                Rex::push_connection({ssh => $ssh, server => $server, sftp => $ssh->sftp?$ssh->sftp:undef, cache => Rex::Cache->new});
@@ -277,6 +315,12 @@ sub run {
                # auth unsuccessfull
                unless($auth_ret) {
                   Rex::Logger::info("Wrong username or password. Or wrong key.");
+                  # after jobs
+                  for my $code (@{$tasks{$task}->{"after"}}) {
+                     &$code($server, 1);
+                  }
+
+
                   CORE::exit 1;
                }
 
@@ -295,6 +339,11 @@ sub run {
             # run the task
             $ret = _exec($task, \%opts);
 
+            # around jobs
+            for my $code (@{$tasks{$task}->{"around"}}) {
+               &$code($server);
+            }
+
             # disconnect if ssh connection
             if(! $tasks{$task}->{"no_ssh"} && $server ne "localhost" && $server ne $shortname) {
                Rex::Logger::debug("Disconnecting from $server");
@@ -304,6 +353,11 @@ sub run {
             # remove remote connection from the stack
             Rex::pop_connection();
 
+            # after jobs
+            for my $code (@{$tasks{$task}->{"after"}}) {
+               &$code($server);
+            }
+
             # close logger
             Rex::Logger::shutdown();
 
